Enum quest_bind::QuestError
source · pub enum QuestError {
InvalidQuESTInputError {
err_msg: String,
err_func: String,
},
NulError(NulError),
IntoStringError(IntoStringError),
ArrayLengthError,
QubitIndexError,
NotDensityMatrix,
NegativeProbability,
}Variants
InvalidQuESTInputError
An exception thrown by the C library. From QuEST documentation:
An internal function is called when invalid arguments are passed to a QuEST API call, which the user can optionally override by redefining. This function is a weak symbol, so that users can choose how input errors are handled, by redefining it in their own code. Users must ensure that the triggered API call does not continue (e.g. the user exits or throws an exception), else QuEST will continue with the valid input and likely trigger a seg-fault. This function is triggered before any internal state-change, hence it is safe to interrupt with exceptions.
See also invalidQuESTInputError().
NulError(NulError)
IntoStringError(IntoStringError)
ArrayLengthError
QubitIndexError
NotDensityMatrix
NegativeProbability